package MFRotation;
use strict;
use warnings;

use rlib "./";

use MFValue;
use base qw(MFValue);

use SFRotation;
our $SField = new SFRotation;

1;
__END__
